Crate open_cypher

Crate open_cypher 

An unofficial, syntax-only lexer and parser targeting openCypher 2024.3.

The crate exposes a lossless token stream, an owned and spanned AST, and structured diagnostics. It deliberately does not perform semantic analysis or query execution.

Re-exports

pub use diagnostic::Diagnostic;
pub use diagnostic::DiagnosticCode;
pub use diagnostic::Label;
pub use diagnostic::ParseErrors;
pub use diagnostic::Severity;
pub use lexer::LexOutcome;
pub use lexer::lex;
pub use parser::ParseOutcome;
pub use parser::ParsedProgram;
pub use parser::parse;
pub use parser::parse_recovering;
pub use span::Span;
pub use token::Keyword;
pub use token::Token;
pub use token::TokenKind;

Modules

ast
A fully owned, syntax-oriented openCypher abstract syntax tree.
diagnostic
Structured, parser-backend-neutral diagnostics.
lexer
Lossless openCypher tokenization built with Logos.
parser
Strict and recovering parser entry points.
span
Source locations used throughout the lexer, parser, and syntax tree.
token
Backend-neutral lexical tokens.

Constants

OPEN_CYPHER_GRAMMAR_REVISION
The immutable upstream Git revision containing the language snapshot.
OPEN_CYPHER_GRAMMAR_VERSION
The upstream openCypher language release used as this crate’s pinned baseline.