Keyword

Enum Keyword 

#[non_exhaustive]
pub enum Keyword {
Show 67 variants Acyclic, All, AllShortestPaths, And, Any, As, Asc, Ascending, By, Call, Case, Collect, Contains, Count, Create, Delete, Desc, Descending, Detach, Distinct, Else, End, Ends, Exists, False, Group, Groups, In, Inf, Infinity, Is, Limit, Match, Merge, Nan, None, Not, Null, Offset, On, Optional, Or, Order, Path, Paths, Reduce, Remove, Return, Set, Shortest, ShortestPath, Simple, Single, Skip, Starts, Then, Trail, Trim, True, Union, Unwind, Walk, When, Where, With, Xor, Yield,
}
A word recognized specially by this crate’s lexer.

This contains the openCypher 2024.3 keyword spellings plus the documented path-mode and subquery-expression extensions consumed by the grammar. The parser decides whether a keyword can act as a symbolic name at a particular location.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Acyclic



All



AllShortestPaths



And



Any



As



Asc



Ascending



By



Call



Case



Collect



Contains



Count



Create



Delete



Desc



Descending



Detach



Distinct



Else



End



Ends



Exists



False



Group



Groups



In



Inf



Infinity



Is



Limit



Match



Merge



Nan



None



Not



Null



Offset



On



Optional



Or



Order



Path



Paths



Reduce



Remove



Return



Set



Shortest



ShortestPath



Simple



Single



Skip



Starts



Then



Trail



Trim



True



Union



Unwind



Walk



When



Where



With



Xor



Yield

Implementations

Source

impl Keyword

pub const fn as_str(self) -> &'static str

Returns the canonical uppercase spelling.

pub fn from_ascii_case_insensitive(text: &str) -> Option<Self>

Recognizes an ASCII keyword without regard to case.

Non-ASCII input is never a keyword.